"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const archy_1 = __importDefault(require("archy"));
/**
 * Given an addon name, a hash of dependents by version (as returned by discoverAddonVersions),
 * and optionally a function to determine how the addon itself is printed, returns a string
 * containing a printable version of the structure.
 */
function dependentsToString(name, instances, printer) {
    const tree = {};
    for (const cacheKey of Object.keys(instances)) {
        const instance = instances[cacheKey];
        const { version, runtime, dependents } = instance;
        for (const dependent of dependents) {
            let node = tree;
            for (const layer of dependent) {
                if (!node[layer])
                    node[layer] = {};
                node = node[layer];
            }
            if (printer) {
                node[name] = printer(version, cacheKey, runtime);
            }
            else {
                let details = [];
                if (cacheKey && cacheKey !== version) {
                    details.push(`cacheKey: ${cacheKey}`);
                }
                if (runtime) {
                    details.push(`runtime: true`);
                }
                node[name] = `${name}@${version}`;
                if (details.length > 0) {
                    node[name] += ` (${details.join(', ')})`;
                }
            }
        }
    }
    const root = Object.keys(tree)[0];
    return archy_1.default(transformTree(root, name, tree[root]));
}
exports.default = dependentsToString;
// Transform the tree from a structure that's convenient to build into the one archy expects
function transformTree(name, addon, tree) {
    return {
        label: name,
        nodes: sortKeys(addon, tree).map((key) => {
            if (key === addon) {
                return tree[key];
            }
            else {
                return transformTree(key, addon, tree[key]);
            }
        }),
    };
}
// Boost the addon in question to the top, then alphabetize the rest
function sortKeys(addon, tree) {
    return Object.keys(tree).sort((a, b) => {
        if (a === addon) {
            return -1;
        }
        else if (b === addon) {
            return 1;
        }
        else {
            return a < b ? -1 : 1;
        }
    });
}
//# sourceMappingURL=dependents-to-string.js.map